#include <owl.h>
#include <bwcc.h>
#include <string.h>

#define PASSWORDLEN 8
#define USERNAMELEN 8
#define ID_USERNAME 101
#define ID_PASSWORD 102

// Define application class derived from  TApplication
class myTest : public TApplication
{
public:
	myTest(LPSTR AName, HANDLE hInstance, HANDLE hPrevInstance, LPSTR lpCmdLine, int nCmdShow)
		: TApplication(AName, hInstance, hPrevInstance, lpCmdLine, nCmdShow) {};
	~myTest();

protected:
	virtual void InitMainWindow();
	virtual void InitInstance();

private:
	char *Password;
	char *UserName;

};

// Declare TMainWindow, a Twindow descendant
class TMainWindow : public TWindow
{
public:
	TMainWindow(PTWindowsObject AParent, LPSTR ATitle, PTModule = NULL);
   ~TMainWindow();

};

class LogonDialog : public TDialog
{
public:
	LPSTR	DlgUserName;
    LPSTR	DlgPassword;

	LogonDialog(LPSTR UserName, LPSTR Password);
	void TransferData(WORD Direction);

protected:
    virtual void Ok(RTMessage Msg) = [ID_FIRST + IDOK];
};



LogonDialog::LogonDialog(LPSTR UserName, LPSTR Password)
			 : TDialog(NULL, "LogonDialog")
	{
	DlgUserName = UserName;
	DlgPassword = Password;

	}

/* Sets and gets the values of the items (controls) of the input
   dialog. */
void LogonDialog::TransferData(WORD Direction)
	{
	if ( Direction == TF_SETDATA )
		{
		SetDlgItemText(HWindow, ID_USERNAME, DlgUserName);
		SetDlgItemText(HWindow, ID_PASSWORD, DlgPassword);
		}
	else
		if ( Direction == TF_GETDATA )
			GetDlgItemText(HWindow, ID_PASSWORD, DlgPassword, PASSWORDLEN);
	}

void LogonDialog::Ok(RTMessage Msg)
	{
	switch( Msg.LP.Hi )
		{
		case BN_CLICKED :
			if( GetDlgItemText(HWindow, ID_PASSWORD, DlgPassword, PASSWORDLEN) == NULL )
            	{
				Msg.Result = IDCANCEL;
				TDialog::Cancel( Msg);
				break;
                }
			TDialog::Ok( Msg );	// perform default
			break;
		}
	}

/****************************************************
 * TMainWindow implementations:
 ****************************************************/

// Define TMainWindow constructor
TMainWindow::TMainWindow(PTWindowsObject AParent, LPSTR ATitle, PTModule AModule)
	: TWindow(AParent, ATitle, AModule)
	{
	}

// Define main window destructor
TMainWindow::~TMainWindow()
	{                                           
	}

/***************************************************
 * TAMISApp method implementations:
 ***************************************************/

// Construct the TAMIS's MainWindow of type TMainWindow
void myTest::InitMainWindow()
	{
	MainWindow = new TMainWindow(NULL, "A Test");
	}

/* Initalize the instance of this application and post the AMISINIT message */

void myTest::InitInstance()
	{
	Password = new char[PASSWORDLEN+1];
	UserName = new char[USERNAMELEN+1];

	strcpy(Password, "");
    strcpy(UserName, "myName");

	TApplication::InitInstance();
	if( Status != 0)
		return;

	switch( ExecDialog(new LogonDialog(UserName, Password) ) )
		{
		case IDOK :
			BWCCMessageBox(NULL, "Ok received", "Dialog Result", MB_ICONHAND);
			break;
		case IDCANCEL :
			BWCCMessageBox(NULL, "Cancel received", "Dialog Result", MB_ICONHAND);
			break;
		default :
			BWCCMessageBox(NULL, "Undefined received", "Dialog Result", MB_ICONHAND);
			break;
		}
	}

// Destructor when application terminating
myTest::~myTest()
	{
	delete[] Password;
	delete[] UserName;
	}

// Main program
int PASCAL WinMain(HANDLE hInstance,
				   HANDLE hPrevInstance,
				   LPSTR lpCmdLine,
				   int nCmdShow)
{

	myTest Appl("Amis Main Window", hInstance, hPrevInstance, lpCmdLine, nCmdShow);

	if(!BWCCGetVersion() )
    	{
		MessageBox(NULL, "Unable to load Borland Controls", "System Error", MB_OK | MB_ICONHAND);
		return -1;
        }


	Appl.Run();

	return Appl.Status;
}

